# msgpack-types [![PyPI](https://img.shields.io/pypi/v/msgpack-types.svg)](https://pypi.org/project/msgpack-types/)

> Type stubs for [msgpack](https://github.com/msgpack/msgpack-python)

Allows for autocomplete and static typing.

## install

```
pip install msgpack-types
```

## related

- <https://github.com/sbdchd/django-types>
- <https://github.com/sbdchd/djangorestframework-types>
- <https://github.com/sbdchd/celery-types>
- <https://github.com/sbdchd/mongo-types>
